pub enum AdminAuthenticationStep {
Password {
password: String,
},
Question {
question: String,
answer: String,
},
EmailConfirmation,
}Expand description
Information about authentication.
This is only available options to create user with only a single step. No confirmation needed at all. If provided data is incorrect, you can edit it or delete user completely.
Also, user can change it’s data (including authentication flows) by user methods, not application methods.
Variants