pub enum IdenticationRequirement {
Nickname {
spaces: bool,
upper_registry: bool,
characters: bool,
},
Email {
exclude_email_domains: Vec<String>,
},
}Expand description
Identication requirement.
This is how you should require proper identication from user as a application backend’s administrator.
Variants
Nickname
Simple nickname identication.
You can specify:
- Allowance of spaces (e.g.,
pimple crawler) - Allowance of upper-registry letters (e.g.,
HelloKitty1983) - Allowance of characters except
_&-(e.g.,MainForce **ELIGE**)
Email identication.
You can specify email domains that you want to exclude (for example, that domains which supports temporary registration).
Implementations
Sourceimpl IdenticationRequirement
impl IdenticationRequirement
Sourcepub fn simple_nickname() -> Self
pub fn simple_nickname() -> Self
Creates a simple nickname requirement.
Sourcepub fn nickname_with_opts(
spaces: bool,
upper_registry: bool,
characters: bool,
) -> Self
pub fn nickname_with_opts( spaces: bool, upper_registry: bool, characters: bool, ) -> Self
Creates a nickname requirement with options.
Sourcepub fn simple_email() -> Self
pub fn simple_email() -> Self
Creates a simple email requirement.
Sourcepub fn email_with_opts(exclude_email_domains: &[impl ToString]) -> Self
pub fn email_with_opts(exclude_email_domains: &[impl ToString]) -> Self
Creates an email requirement with options.