#[non_exhaustive]pub enum StatelessHint {
Password {
min_size: usize,
should_contain_different_case: bool,
should_contain_symbols: bool,
},
Totp {
alg: String,
generated_secret: String,
},
U2f {
challenge: Challenge,
},
Email {
salt: String,
hash: Vec<u8>,
},
}Expand description
Stateless data of creating user step.
This type is used to be stored in preregistration state on client-side while registering to minimize C3A storage usage.
Read-only due to storage a copy in signed tokens.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Password
Password data is only to clients (to provide clues about requirements).
Totp
Information about TOTP 2FA. User should save these options in their TOTP applications (for example, Google Authenticator or KeePass).
U2f
U2F challenge.
Email confirmation code hash & salt.