pub struct GeneralAuthenticationRequirement(/* private fields */);Expand description
Authentication requirement.
Implementations
Sourceimpl GeneralAuthenticationRequirement
impl GeneralAuthenticationRequirement
Sourcepub fn password(
min_size: usize,
should_contain_different_case: bool,
should_contain_symbols: bool,
) -> Self
pub fn password( min_size: usize, should_contain_different_case: bool, should_contain_symbols: bool, ) -> Self
Simple password.
You can specify minimal size, lower & upper case requirement and symbols requirement.
Sourcepub fn totp() -> Self
pub fn totp() -> Self
Standard TOTP 2FA.
Default algorithm is SHA1, default length in bytes - 20 (160 bits).
It’s recommended to use SHA256/SHA512 and 32 bytes of secret, if your
2FA application supports this.
Other parameters: 6 digits, 1 skew step, 30 seconds to step.
Related RFC:
Rust realization: totp-rs.
Sourcepub fn totp_with_opts(
algorithm: TOTPAlgorithm,
secret_length_bytes: Option<usize>,
) -> Self
pub fn totp_with_opts( algorithm: TOTPAlgorithm, secret_length_bytes: Option<usize>, ) -> Self
TOTP 2FA with options.
Default algorithm is SHA1, default length in bytes - 20 (160 bits).
It’s recommended to use SHA256/SHA512 and 32 bytes of secret, if your
2FA application supports this.
Other parameters: 6 digits, 1 skew step, 30 seconds to step.
Related RFC:
Rust realization: totp-rs.
Sourcepub fn question() -> Self
pub fn question() -> Self
Question.
According to this requirement, the user must give the correct answer to the question that he had given to him.
Sourcepub fn email_confirm() -> Self
pub fn email_confirm() -> Self
Email confirmation.
Note that this requirement is already satisfy excluded domain identication requirement. It just requests email code every time user signs in.
Sourcepub fn as_variant(&self) -> &GeneralAuthenticationRequirementVariant
pub fn as_variant(&self) -> &GeneralAuthenticationRequirementVariant
Returns variant.
Sourceimpl GeneralAuthenticationRequirement
impl GeneralAuthenticationRequirement
Sourcepub fn generate_requirement_for_user(&self) -> AuthenticationRequirement
pub fn generate_requirement_for_user(&self) -> AuthenticationRequirement
Generates authentication requirement you can provide to users.