pub struct SignUpOpts {
pub identify_by: IdenticationRequirement,
pub allow_sign_up: bool,
pub auto_assign_tags: Vec<AccessTag>,
pub allowed_authn: Vec<GeneralAuthenticationRequirement>,
pub required_authn: Vec<GeneralAuthenticationRequirement>,
}Expand description
Sign up options.
Fields
identify_by: IdenticationRequirementIdentication requirement.
Email by default.
allow_sign_up: boolYou can temporarily disable user registration.
Enabled by default.
Assign given tags on common user registration.
allowed_authn: Vec<GeneralAuthenticationRequirement>Users can choose any requirements from this list to construct their own authentication flow. But you can also strict their flows as application backend developers by frontend limiting.
required_authn: Vec<GeneralAuthenticationRequirement>These requirements are mandatory to choose in every single authentication flow.
Implementations
Sourceimpl SignUpOpts
impl SignUpOpts
Sourcepub fn with_id_type(self, id_type: IdenticationRequirement) -> Self
pub fn with_id_type(self, id_type: IdenticationRequirement) -> Self
Specifies identification requirement.
Sourcepub fn with_signup_enabled(self, enabled: bool) -> Self
pub fn with_signup_enabled(self, enabled: bool) -> Self
Enables or disables new users’ registration.
Specifies auto-assign tags.
Sourcepub fn with_allowed_steps(
self,
steps: &[GeneralAuthenticationRequirement],
) -> Self
pub fn with_allowed_steps( self, steps: &[GeneralAuthenticationRequirement], ) -> Self
Specifies allowed authentication steps.
Sourcepub fn with_required_steps(
self,
steps: &[GeneralAuthenticationRequirement],
) -> Self
pub fn with_required_steps( self, steps: &[GeneralAuthenticationRequirement], ) -> Self
Specifies required authentication steps.