pub struct UserAuthorizeResponse {
pub approved: bool,
pub id: Option<Id>,
pub new_access_token: Option<String>,
pub new_cba_challenge: Option<Vec<u8>>,
pub new_cba_token: Option<String>,
}Expand description
Authorize response.
Fields
approved: boolGrants permissions to the resource.
id: Option<Id>Identifies the user.
new_access_token: Option<String>May contains new access token.
Application backend must update it in the application client.
new_cba_challenge: Option<Vec<u8>>May contains new client-based authorization challenge.
Application backend must transfer this challenge to the application client
and repeat request after getting cba_challenge_sign from it.
Note that application backend also must transfer challenge state from the headers!
new_cba_token: Option<String>May contains new client token.
Application backend must update it in the application client.