UserLogoutRequest

Struct UserLogoutRequest 

pub struct UserLogoutRequest {
    pub access_token: String,
    pub refresh_token: String,
}
Request to log out.

Note that logout revokes refresh token, but access token is still valid for at least 15 minutes by default (see TokenLifetimes). Revoke can be made without even client token if it is compromised.

Fields

access_token: String

Access token (MPAAT).

refresh_token: String

Refresh token (random bytes).

Implementations

Source

impl UserLogoutRequest

pub fn new(act: impl ToString, rft: impl ToString) -> Self

Creates new user logout request.