Authnz common library.
Contains common types and utils for Impulse Authnz server & SDKs.
Re-exports
pub use chrono;
Structs
- Access
Tag - Access tag.
- AppAuth
Configuration - Application config.
- AppAuth
Configuration Builder - Configuration builder.
- AppCreate
User Request - Request to create user for given application as admin.
- Application
Authorize Response - Simple response with permission grant.
- Authentication
Approval - Authentication step approval.
- Authentication
Flow - Single authentication flow.
- Authentication
Flow Verifiers - Single authentication flow.
- Authentication
Flows - Authentication flows.
- Authentication
Flows Verifiers - Authentication flows.
- Authentication
State - Authentication state.
- CBAChallenge
Sign - Client-based token state’s challenge approval.
- CBAChallenge
State - Payload of client-based authorization approval state.
- CBAUpdate
Request - Request to immediately update client token.
- CBAUpdate
Response - Update client token response.
- Cipher
Key - Encryption key.
- Client
Based Authorization Opts - Client-based authorization options.
- Dilithium5
Signature - Dilithium5 raw signature.
- Edit
AppAuth Configuration Request - Edit application config request.
- Edit
User Tags Request - Edit user tags request.
- Email.
- Fail2
BanOptions - Fail2ban options.
- General
Authentication Requirement - Authentication requirement.
- Generate
Invitation Request - Used by C3A administrator for invite generation.
- GetApp
Auth Configuration Request - Requests application config.
- GetApp
Auth Configuration Response - Application config response.
- GetUser
Tags Response - Get user tags response.
- Invite
- Unique invitation code.
- LightMPAAT
Header - LMPAAT header: unencrypted metadata.
- LightMPAAT
Payload - LMPAAT payload: unencrypted metadata.
- LightMPAAT
Signature - LMPAAT signature: unencrypted signature of header and payload.
- Login
Request - Login request.
- MPAAT
Header - MPAAT header: unencrypted metadata to acquire the payload.
- MPAAT
Payload - MPAAT payload: encrypted user metadata.
- MPAAT
Signature - MPAAT signature: unencrypted signature of header and payload.
- Prefetch
Login Response - Response with list of allowed authentication flows and client-based authorization challenge.
- Preregistration
Requirements Request - Preregistration request.
- Preregistration
Requirements Response - Preregistration response.
- Register
AppAuth Configuration Request - Configuration struct for registering your application in C3A.
- Register
AppAuth Configuration Response - Application registration response.
- Register
User Request - Registration request.
- Remove
AppBy Admin Request - Requests application removal by C3A admin.
- Server
Error - Data structure responsible for server errors.
- Sign
InMetrics - Metrics used with
fail2ban. - Sign
InOpts - Sign in options.
- Sign
Keypair - Signing key (certificate).
- Sign
UpOpts - Sign up options.
- Token
Bundle - Access, refresh and client tokens.
- Token
Lifetimes - Tokens’ lifetimes.
- User
Authorize Request - Request to authorize.
- User
Authorize Request Builder - Request builder.
- User
Authorize Response - Authorize response.
- User
Data - User data stored in key-value DB.
- User
Logout Request - Request to log out.
Enums
- Admin
Authentication Step - Information about authentication.
- Approval
Variant - Approval variant.
- Authentication
Approval Verifier - Information about authentication that is stored in key-value DB.
- Authentication
Requirement - Requirement to construct authentication flows.
- Dilithium5
RawCertificate Validation Requirement - Dilithium5 raw certificate validation requirement.
- General
Authentication Requirement Variant - Authentication requirement.
- Id
- User identifier.
- Identication
Requirement - Identication requirement.
- Stateless
Hint - Stateless data of creating user step.
- TOTP
Algorithm - TOTP algorithm.
- Token
Encryption Type - Token encryption type.
- X509
Certificate Validation Requirement - X.509 certificate validation requirement.
Constants
- ACCESS_
TOKEN - Access token header/cookie name.
- CLIENT_
CHALLENGE - Client challenge header name.
- CLIENT_
CHALLENGE_ SIGN - Client challenge sign header name.
- CLIENT_
CHALLENGE_ TOKEN - Client challenge token header name.
- CLIENT_
TOKEN - Client token header/cookie name.
- FORWARDED_
FROM - Forwarded from header name.
- REFRESH_
TOKEN - Refresh token header/cookie name.
- SIGN
- Sign header name.
- SIGNUP_
HINTS - Stateless hints header name.
Functions
- base64_
decode - Decodes data with
URL_SAFEbase64 engine. - base64_
encode - Encodes data by
URL_SAFEbase64 engine. - deploy_
lmpaat - Creates LMPAAT from given data.
- deploy_
mpaat - Creates MPAAT from given data.
- generate
- Generates
SZof random bytes. - lmpaat_
extract_ common_ fields - Extracts
common_fieldsfrom LMPAAT token. - lmpaat_
extract_ payload - Extracts
payloadfrom LMPAAT token. - mpaat_
extract_ common_ fields - Extracts
common_fieldsfrom MPAAT token. - mpaat_
extract_ payload - Extracts
payloadfrom MPAAT token. - mpaat_
extract_ payload_ with_ metadata - Extracts
payloadwith its metadata from MPAAT token. - mpaat_
extract_ payload_ with_ metadata_ exp_ ignored - Extracts
payloadwith its metadata from MPAAT token. - split_
token - Splits the token if it exceeds
max_len. - take_
exp_ from_ duration - Makes timestamp of expiration from duration and current system time.
- unite_
token - Unites a token from its parts.
Type Aliases
- Admin
Authentication Flow Request - Authentication flow specified to be used by admin.
- Check
User Exists Request - Check user exists request.
- Delete
User Request - Get user tags request.
- GetUser
Tags Request - Get user tags request.
- MResult
- Simple backend result type.
- Prefetch
Login Request - Prelogin request.
- Remove
AppRequest - Requests application removal from C3A.