IdenticationRequirement

Enum IdenticationRequirement 

pub enum IdenticationRequirement {
    Nickname {
        spaces: bool,
        upper_registry: bool,
        characters: bool,
    },
    Email {
        exclude_email_domains: Vec<String>,
    },
}
Identication requirement.

This is how you should require proper identication from user as a application backend’s administrator.

Variants



Nickname

Simple nickname identication.

You can specify:

  1. Allowance of spaces (e.g., pimple crawler)
  2. Allowance of upper-registry letters (e.g., HelloKitty1983)
  3. Allowance of characters except _ & - (e.g., MainForce **ELIGE**)

Fields

spaces: bool
upper_registry: bool
characters: bool


Email

Email identication.

You can specify email domains that you want to exclude (for example, that domains which supports temporary registration).

Fields

exclude_email_domains: Vec<String>

Implementations

Source

impl IdenticationRequirement

pub fn simple_nickname() -> Self

Creates a simple nickname requirement.

pub fn nickname_with_opts( spaces: bool, upper_registry: bool, characters: bool, ) -> Self

Creates a nickname requirement with options.

pub fn simple_email() -> Self

Creates a simple email requirement.

pub fn email_with_opts(exclude_email_domains: &[impl ToString]) -> Self

Creates an email requirement with options.

pub fn validate(&self, id: impl AsRef<str>) -> MResult<()>

Validates an identifier given by user.