SignUpOpts

Struct SignUpOpts 

pub struct SignUpOpts {
    pub identify_by: IdenticationRequirement,
    pub allow_sign_up: bool,
    pub auto_assign_tags: Vec<AccessTag>,
    pub allowed_authn: Vec<GeneralAuthenticationRequirement>,
    pub required_authn: Vec<GeneralAuthenticationRequirement>,
}
Sign up options.

Fields

identify_by: IdenticationRequirement

Identication requirement.

Email by default.

allow_sign_up: bool

You can temporarily disable user registration.

Enabled by default.

auto_assign_tags: Vec<AccessTag>

Assign given tags on common user registration.

allowed_authn: Vec<GeneralAuthenticationRequirement>

Users can choose any requirements from this list to construct their own authentication flow. But you can also strict their flows as application backend developers by frontend limiting.

required_authn: Vec<GeneralAuthenticationRequirement>

These requirements are mandatory to choose in every single authentication flow.

Implementations

Source

impl SignUpOpts

pub fn new() -> Self

Creates new options.

pub fn with_id_type(self, id_type: IdenticationRequirement) -> Self

Specifies identification requirement.

pub fn with_signup_enabled(self, enabled: bool) -> Self

Enables or disables new users’ registration.

pub fn with_auto_tags(self, tags: &[impl Into<AccessTag> + Clone]) -> Self

Specifies auto-assign tags.

pub fn with_allowed_steps( self, steps: &[GeneralAuthenticationRequirement], ) -> Self

Specifies allowed authentication steps.

pub fn with_required_steps( self, steps: &[GeneralAuthenticationRequirement], ) -> Self

Specifies required authentication steps.